SciExp² documentation contents
==============================


:Release: |version|
:Date: |today|

Contents:

.. toctree::
   :numbered:
   :maxdepth: 2

   introduction.rst
   user_guide.rst
   reference.rst

.. toctree::
   :hidden:

   news.rst
   todo.rst


Indices and tables
==================

* :ref:`news`
* :ref:`todo`
* :ref:`genindex`
* :ref:`modindex`
